c ######################################################################
c #
c #                  Sn-4Ag PROPERTIES PACKAGE
c #                  ------------------------
c # Contains functions for the calculation of the thermo-physical
c # properties of Sn-4Ag
c #
c ######################################################################

c ######################################################################
      real function dSn4Ag(T)
c ######################################################################
c #
c # Density of Sn-4Ag
c #
c # Range: 0 <= T <= inf K
c #
c #                        References
c #                        ----------
c # Cryocomp v3.0
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   dSn4Ag          x    density                           Kg/m**3
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 1.0   June 2015
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      dSn4Ag = 7489.0
c *

      return
      end
c ######################################################################
      real function cSn4Ag(T)
c ######################################################################
c #
c # Specific heat of Sn-4Ag
c #
c # Range: 1 <= T <= 300 K
c #
c #                        References
c #                        ----------
c # BNL Database for white Tin 
c # CryoComp v3.0 for Silver
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   cSn4Ag          x    specific heat                     J/Kg K
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 1.0   June 2015
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables
      real     Tmin,Tmax,T0,T1
      real     A1,A2,A3
      real     B0,B1,B2,B3,B4
      real     AA,CC,DD,a,c,d,na,nc,nd
c
      data     Tmin / 1.0 /, Tmax / 300.0/
c      data     T0 / 9.78513319 /, T1 / 20.3231577 /
      data     T0 / 4.8 /, T1 / 20.3231577 /
c
      data     A1  / 2.24E-02   / ,  A2  / -1.07E-02 / ,
     &         A3  / 5.21E-03  /
      data     B0  / 4.35074143  / ,  B1 / -2.19106641 / ,
     &         B2  / 0.31525974  / ,  B3 / -6.02E-03   / ,
     &         B4  / 2.02E-06    /
      data     AA  / -30.8905545  / ,
     &         CC  / 131.86606  / ,  DD  / 173.148992  / 
      data     a   / 36.0496527  / , 
     &         c   / 13.3270114  / ,  d   /  9.36187287 / 
      data     na  / 0.60266973  / ,
     &         nc  / 2.97517155 / ,  nd  / 3.84929332 / 
      save    
c * local variables
      real     TT

c *
      TT=T
      TT=min(TT,Tmax)
      TT=max(TT,Tmin)

      if(TT.le.T0) then

         cSn4Ag = A1*TT + A2*TT**2 + A3*TT**3

      elseif(TT.ge.T0.and.TT.le.T1) then

         cSn4Ag = B0 + B1*TT + B2*TT**2 + B3*TT**3 + B4*TT**4

      else
      
         cSn4Ag = AA*TT**1/(a+TT)**na + 
     &            CC*TT**3/(c+TT)**nc + DD*TT**4/(d+TT)**nd       

      endif

c *
      return
      end
c ######################################################################
      real function kSn4Ag(T)
c ######################################################################
c #
c # Thermal conductivity of Sn-4Ag
c #
c # Range: 2 <= T <= 300 K
c #
c #                        References
c #                        ----------
c # N. Bagrets, C. Barth and K.-P Weiss 
c # Low Temperature Thermal and Thermo-Mechanical Properties of
c # Soft Solders for Superconducting Applications
c # IEEE Transactions on Applied Superconductivity,
c # Vol 24, No. 2, 3 June 2014
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   kSn4Ag          x    thermal conductivity              W/m K
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 1.0   June 2015
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables
      real     Tmin,Tmax,T0
      real     rho0,rho273,RRR
      real     alpha,alpha2,beta
      real     L0,K0
      real     m,n,arg1,arg2
      real     W0,Wi,Wi0
      real     l
c *
      data     Tmin / 2.0/, Tmax / 300.0/
      data     T0 / 5.6279166 /
      data     rho273 / 1.33E-07 / , RRR / 150.0 /
      data     alpha2 / 3.4204573E-08 /
      data     L0 / 2.44E-08 / , K0 / 6.37E+01 /
      data     m / 1.9413655 /, n / 1.7728749 /
      data     l / 1.36579797 /
      save    
c * local variables
      real     TT

c *
      TT=T
      TT=min(TT,Tmax)
      TT=max(TT,Tmin)

      rho0 = rho273/(RRR-1)
      beta = rho0/L0
      arg1 = (m-n)*(m+l)
      arg2 = (TT-T0)/T0
      alpha = alpha2*(beta/n/alpha2)**arg1
      W0 = beta/TT
      Wi = alpha*TT**n
      Wi0 = Wi+W0

      if(TT.le.T0) then

         kSn4Ag = 1/Wi0

      else

         kSn4Ag = 1/Wi0 + K0*(1-exp(-arg2))

      endif

c *
      return
      end
c ######################################################################
      real function rSn4Ag(T)
c ######################################################################
c #
c # Electrical resistivity of Sn-4Ag
c #
c # Range: 0 <= T <= 300 K
c #
c #                        References
c #                        ----------
c # N. Bagrets, C. Barth and K.-P Weiss 
c # Low Temperature Thermal and Thermo-Mechanical Properties of
c # Soft Solders for Superconducting Applications
c # IEEE Transactions on Applied Superconductivity,
c # Vol 24, No. 2, 3 June 2014
cc #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   rSn4Ag          x    resistivity                       Ohm m
c #
c # Author : L.Bottura at CryoSoft
c # Version: 1.0   June 2015
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables
      real     RRR,rho273,rho0,rhoi,rhoi0
      real     p1,p2,p3,p4,p5,p6,p7
      real     arg
      real     Tmin,Tmax
c
      data     RRR / 150.0 /, rho273 / 1.33E-07 /
      data     p1 / 2.08086139E-14 /, p2 / 3.74042567 /,
     &         p3 / 1.38706992E+10 /, p4 / -1.33 /,
     &         p5 / 10.0 /, p6 / 1.0 / ,
     &         p7 / 0.333 /
      data     Tmin   / 0.0/, Tmax   / 300.0/
      save
c * local variables
      real     TT

c *
      TT=T
      TT=min(TT,Tmax)
      TT=max(TT,Tmin)

      rho0 = rho273/(RRR-1)
      arg = (p5/TT)**p6
      rhoi = p1*TT**p2/(1.+p1*p3*TT**(p2+p4)*exp(-arg))
      rhoi0 = (p7*rhoi*rho0)/(rhoi+rho0)

      rSn4Ag = rho0+rhoi+rhoi0
	
c *
      return
      end
